GraphqlError class final

Implemented types
Annotations
  • @immutable

Constructors

GraphqlError({required String message, required IList<PathItem> path, required String? extensionsCode})
const

Properties

extensionsCode → String?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
path → IList<PathItem>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited