QueryFieldField class final

Implemented types

Constructors

QueryFieldField(String fieldName, {IList<QueryFieldArg> args = const IListConst([]), String? aliasName, required String description, required GraphQLOutputTypeConsiderListNull return_})
const

Properties

aliasName → String
final
args → IList<QueryFieldArg>
final
description → String
final
fieldName → String
final
hashCode → int
The hash code for this object.
no setterinherited
return_ → GraphQLOutputTypeConsiderListNull
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAliasName(String aliasName) → QueryFieldField
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited