Variable<T> class final

Inheritance
Annotations
  • @immutable

Constructors

Variable(String name)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryInput({required GraphQLType type, required QueryInput staticValueToQueryInputFunc(T)}) → QueryInput
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited